HavocBot
########

HavocBot is an extensible chat bot that works across any number of chat programs

Credits
------
**Mark Perdue** (`markaperdue <https://github.com/markperdue>`_, https://www.righteousbanana.com)
